package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````P"4```````!``````````#BQ````
M`````````$``.``+`$``&P`:``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"````````J`(````````<`````````!P``````````0`````````!````
M!````````````````````````````````````*@9````````J!D`````````
M$`````````$````%`````"``````````(``````````@````````!3X`````
M```%/@`````````0`````````0````0`````8`````````!@`````````&``
M```````@1@```````"!&`````````!`````````!````!@```-"K````````
MT+L```````#0NP```````%`$````````T!0`````````$`````````(````&
M````X*L```````#@NP```````."[````````$`(````````0`@````````@`
M````````!`````0```#$`@```````,0"````````Q`(```````!$````````
M`$0`````````!`````````!0Y71D!````)">````````D)X```````"0G@``
M``````0!````````!`$````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``#0JP```````-"[````````T+L````````P!````````#`$`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`!````!0````#````
M1TY5`+1(@5R?QSM+R1!S"RNP_E+>\^9:!````!`````!````1TY5```````#
M`````@`````````1````/P````0````(````(!P0``5`!(8H`D`$D(8`A(()
M`"!)(`0(N*(11;H``@H`````/P```$(```!%````1@```$T```!.````4```
M`%0```!5````5P```%@```!;````70```%\``````````````&[%WQ_.WD<M
M:W^:?"[%F[8@_^0.U634?-EQ6!SB1\8!0OK7AZQ+X\"ZXY)\PN4_+/JA;&"S
M`8MO:PE#UF:OS&;%N9Q`0D75[,2)!9"(!W#3.?*+'`T4XI[:S>.>,V+;[16,
M)<P,.I<+5J2;EJ?=HVM^J9R;T67.;>"G`@IK&IY0"HH05Z/@^TD`````````
M````````````````````````````X0```!(`````````````````````````
M?@$``!(`````````````````````````Y`$``!(`````````````````````
M````P@$``!(``````````````````````````0```"``````````````````
M````````ZP$``!(`````````````````````````=P(``!(`````````````
M``````````````(``!(`````````````````````````10$``!(`````````
M````````````````7P(``!(`````````````````````````5P(``!(`````
M````````````````````=````!(`````````````````````````3P,``!(`
M````````````````````````W````!(`````````````````````````(P(`
M`!(`````````````````````````%0(``!(`````````````````````````
MTP$``!(`````````````````````````<`(``!(`````````````````````
M````@`(``!(`````````````````````````-P$``!(`````````````````
M````````!0$``!(`````````````````````````<P$``!(`````````````
M````````````CP$``!(`````````````````````````R@$``!(`````````
M````````````````X`(``!(`````````````````````````8`$``!(`````
M````````````````````^0$``!(`````````````````````````L`$``!(`
M````````````````````````Q`(``!(`````````````````````````O0(`
M`!(`````````````````````````$P$``!(`````````````````````````
M'0```"``````````````````````````-P(``!(`````````````````````
M````5````!(`````````````````````````E0$``!(`````````````````
M````````;`$``!(`````````````````````````@P```!(`````````````
M````````````CP```!(`````````````````````````+`$``!(`````````
M````````````````\@```!(`````````````````````````1@```!(`````
M````````````````````Y@```!(`````````````````````````/@(``!(`
M````````````````````````50$``!(`````````````````````````P```
M`!(`````````````````````````\0$``!(`````````````````````````
MJ0$``!(`````````````````````````K@(``!(`````````````````````
M````AP(``!(`````````````````````````8P```!(`````````````````
M````````M@(``!(`````````````````````````#@(``!(`````````````
M````````````I````!(`````````````````````````(P$``!(`````````
M````````````````3`(``!(`````````````````````````O0$``!(`````
M````````````````````M0$``!(`````````````````````````*0(``!(`
M````````````````````````+````"``````````````````````````!P(`
M`!(`````````````````````````'`(``!(`````````````````````````
MH`(``!(`````````````````````````6`,``!(`#@`@0@```````#X!````
M````A`,``!(`#@"@-P```````-4'````````T0(``!(`#@"P(P````````\"
M````````+`,``!(`#@#0+@````````4`````````&`0``!(`#@#@+@``````
M``("````````3@0``!(`#@"`/P```````)T"````````!`0``!``&``@P```
M````````````````:P,``!(`#@#P,````````"4`````````D0,``!(`#@#@
M60```````)\!````````J0,``!$`$```8`````````0`````````Z`,``!``
M&`"@T```````````````````$`0``!(`#@#@+0```````#``````````)00`
M`!(`#@"0-@````````L!````````-P0``!(`#@#P-0```````'0`````````
MG`,``!``%P``P```````````````````>`,``!(`#@`@,0```````!P`````
M````U@(``!$`&`!`P`````````@`````````9`,``!``%P`@P```````````
M````````UP(``"$`&`!`P`````````@`````````W@,``!$`%P`8P```````
M``@`````````:0(``!$`&`!@P`````````@`````````'`,``!(`#@#@70``
M``````$`````````S@,``!(`#@"`70```````%T`````````H@,``!(`#@#`
M)0```````"L`````````100``!(`#@"`60```````%0`````````G@,``"``
M%P``P```````````````````T0```!$`&``@P`````````0`````````V`(`
M`"$`&`!`P`````````@`````````/0,``!(`#@!P-@```````!T`````````
MD0(``"(`````````````````````````N`,``!(`#@`0+@```````+\`````
M````^@,``!(`#@"`6P```````/L!````````LP```!$`&``PP`````````$`
M````````[0,``!(`#@!`,0```````*8$`````````%])5$U?9&5R96=I<W1E
M<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#
M;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A
M=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R
M;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R
M;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E
M=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E
M=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?
M1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L
M7V%L;&]C`%]?97)R;F]?;&]C871I;VX`8VQO<V4`<'1H<F5A9%]G971S<&5C
M:69I8P!O<&5N-C0`<F5A9`!L<V5E:S8T`&5X:70`<W1R;F-M<`!C;&]S961I
M<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H
M<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?
M9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O
M<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`'-T<F-H
M<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM
M;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N
M`%]?<F5G:7-T97)?871F;W)K`&QI8G!E<FPN<V\N-2XS,@!L:6)P=&AR96%D
M+G-O+C``;&EB8RYS;RXV`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E
M>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E
M9&%T80!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H
M85]U<&1A=&4`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`
M<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`'!A
M<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'-H
M85]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(N-0!'3$E"
M0U\R+C,N-`!'3$E"0U\R+C$T`$=,24)#7S(N,RXR`$=,24)#7S(N-``````"
M``,``@`"`````@`"``(````"``(````"`````@`"``0``@`"``````````,`
M`@`%`````@`#``(``@``````!@````,``@`````````````````'```````"
M``,``@`"`````@`"```````"``(``P`'`````@`"``<``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`"``$``@`!``(``0`!``$``0`!`````@`!
M``(``0`!`````0`!``$``@,``!`````@````=1II"0```P!D!`````````$`
M!0`2`P``$`````````!T&6D)```'`'`$```0````E)&6!@``!@!\!```$```
M`'(9:0D```4`AP0``!`````4:6D-```$`),$```0````=1II"0```@!D!```
M`````-"[````````"`````````"@)@```````-B[````````"`````````!@
M)@````````C`````````"``````````(P````````!C`````````"```````
M``#@8@```````,"_````````!@````4``````````````,B_````````!@``
M``D``````````````-"_````````!@```!T``````````````-B_````````
M!@```"```````````````."_````````!@```"@``````````````.B_````
M````!@```#(``````````````/"_````````!@```#L``````````````/B_
M````````!@```%P``````````````"#`````````!0```%D`````````````
M`##`````````!0```%\``````````````$#`````````!0```$\`````````
M`````&#`````````!0```%,```````````````B^````````!P````$`````
M`````````!"^````````!P````(``````````````!B^````````!P````,`
M`````````````""^````````!P````0``````````````"B^````````!P``
M``8``````````````#"^````````!P````<``````````````#B^````````
M!P````@``````````````$"^````````!P````H``````````````$B^````
M````!P````L``````````````%"^````````!P````P``````````````%B^
M````````!P````T``````````````&"^````````!P````X`````````````
M`&B^````````!P````\``````````````'"^````````!P```!``````````
M`````'B^````````!P```!$``````````````("^````````!P```!(`````
M`````````(B^````````!P```!,``````````````)"^````````!P```!0`
M`````````````)B^````````!P```!4``````````````*"^````````!P``
M`!8``````````````*B^````````!P```!<``````````````+"^````````
M!P```!@``````````````+B^````````!P```!D``````````````,"^````
M````!P```!H``````````````,B^````````!P```!L``````````````-"^
M````````!P```!P``````````````-B^````````!P```!X`````````````
M`."^````````!P```!\``````````````.B^````````!P```"$`````````
M`````/"^````````!P```"(``````````````/B^````````!P```",`````
M``````````"_````````!P```"0```````````````B_````````!P```"4`
M`````````````!"_````````!P```"8``````````````!B_````````!P``
M`"<``````````````""_````````!P```"D``````````````"B_````````
M!P```"H``````````````#"_````````!P```"L``````````````#B_````
M````!P```"P``````````````$"_````````!P```"T``````````````$B_
M````````!P```"X``````````````%"_````````!P```"\`````````````
M`%B_````````!P```#```````````````&"_````````!P```#$`````````
M`````&B_````````!P```#,``````````````'"_````````!P```#0`````
M`````````'B_````````!P```#4``````````````("_````````!P```#8`
M`````````````(B_````````!P```#<``````````````)"_````````!P``
M`#@``````````````)B_````````!P```#D``````````````*"_````````
M!P```#H``````````````*B_````````!P```#P``````````````+"_````
M````!P```#T``````````````+B_````````!P```#X`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%S9\``$B%P'0"_]!(@\0(PP```````````/\UTIT``/\EU)T`
M``\?0`#_)=*=``!H`````.G@_____R7*G0``:`$```#IT/____\EPIT``&@"
M````Z<#_____);J=``!H`P```.FP_____R6RG0``:`0```#IH/____\EJIT`
M`&@%````Z9#_____):*=``!H!@```.F`_____R6:G0``:`<```#I</____\E
MDIT``&@(````Z6#_____)8J=``!H"0```.E0_____R6"G0``:`H```#I0/__
M__\E>IT``&@+````Z3#_____)7*=``!H#````.D@_____R5JG0``:`T```#I
M$/____\E8IT``&@.````Z0#_____)5J=``!H#P```.GP_O___R52G0``:!``
M``#IX/[___\E2IT``&@1````Z=#^____)4*=``!H$@```.G`_O___R4ZG0``
M:!,```#IL/[___\E,IT``&@4````Z:#^____)2J=``!H%0```.F0_O___R4B
MG0``:!8```#I@/[___\E&IT``&@7````Z7#^____)1*=``!H&````.E@_O__
M_R4*G0``:!D```#I4/[___\E`IT``&@:````Z4#^____)?J<``!H&P```.DP
M_O___R7RG```:!P```#I(/[___\EZIP``&@=````Z1#^____)>*<``!H'@``
M`.D`_O___R7:G```:!\```#I\/W___\ETIP``&@@````Z>#]____)<J<``!H
M(0```.G0_?___R7"G```:"(```#IP/W___\ENIP``&@C````Z;#]____);*<
M``!H)````.F@_?___R6JG```:"4```#ID/W___\EHIP``&@F````Z8#]____
M)9J<``!H)P```.EP_?___R62G```:"@```#I8/W___\EBIP``&@I````Z5#]
M____)8*<``!H*@```.E`_?___R5ZG```:"L```#I,/W___\E<IP``&@L````
MZ2#]____)6J<``!H+0```.D0_?___R5BG```:"X```#I`/W___\E6IP``&@O
M````Z?#\____)5*<``!H,````.G@_/___R5*G```:#$```#IT/S___\E0IP`
M`&@R````Z<#\____)3J<``!H,P```.FP_/___R4RG```:#0```#IH/S___\E
M*IP``&@U````Z9#\____)2*<``!H-@```.F`_/___R52G```9I``````````
M`$%454B#[#B)?"0<2(U\)!Q(B70D$$B-="002(E4)`A(C50D"&1(BP0E*```
M`$B)1"0H,<#H%_[__TB+-?";``!(BSWQFP``2(GRZ/$Y``"`/2J<````=2_H
M4_W__TB)!82L``!(B<=(A<`/A)`!``#HF_S__XL]]9L``.C@_?__QH#I"0``
M`(L]XYL``.C._?__BSW8FP``@(@Z!````NB\_?__@(@Z!````8M$)!R->`1$
MC6`#2&/_2,'G`^@N_?__2(M,)!"+="0<28G!2(D%"ZP``$B+`4F)`4B-!3P]
M``!)B4$(2(L%>YL``$F)01!(C04I/0``28E!&(/^`0^.\0```$B#P0B#Q@.X
M!`````\?@`````!(BSE(8]"#P`%(@\$(28D\T3G&=>M(8_9(P>8#2(L]K:L`
M`$2)XD4QP$R)R4G'!#$`````2(TU;0@``.B(_?__08G$A<!T4TB+/8*K``!(
MC6PD).@@_/__,<!(B>Y(C3UW.P``Z'\!``!(A<!T/4B+/5NK``#HGOO__^@9
M_?__2(M$)"AD2"L$)2@```!U8TB#Q#A$B>!=05S#2(L]+ZL``.BR_?__08G$
MZYQ(BST.JP``2(7_=`?HG!P``.NP2(T]S3H``$B)[N@;`0``2(D%[*H``$B)
MQTB%P'22Z]F^(````.DT____OP$```#HAOW__^A1^___D#'M28G17DB)XDB#
MY/!05$R-!0HX``!(C0VC-P``2(T]S/W___\5YID``/0/'T0``$B-/2F:``!(
MC04BF@``2#GX=!5(BP6VF0``2(7`=`G_X`\?@`````###Q^``````$B-/?F9
M``!(C37RF0``2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!:69``!(A<!T"/_@
M9@\?1```PP\?@`````"`/0&:````=2]52(,]AID```!(B>5T#$B+/8J9``#H
M'?W__^AH____Q@79F0```5W##Q^``````,,/'X``````Z7O___]F+@\?A```
M````D$%7059!54%455-(@^P(2(7_#X2Q````3(LM<ID``$V%[0^$H0````^V
M!TF)_TB)]83`=`0\/75813'V38ME`$V%Y'0R36/V3(GK9@\?1```3(GR3(G^
M3(GGZ%+Y__^%P'4'0X`\-#UT1TR+8PA(@\,(387D==I(@\0(3(G@6UU!7$%=
M05Y!7\,/'X0``````$F)_D$/MD8!28/&`83`=`0\/77O12G^ZY(/'X``````
M3"GK3XUD-`%(P?L#B5T`Z[4/'X``````13'DZZD/'P!!5D%505154TB![*``
M``!D2(L$)2@```!(B80DF````#'`2(7_=`B`/P!(B?UU,4B+A"28````9$@K
M!"4H````#X4I`0``2('$H````%M=05Q!74%>PV8N#Q^$``````#HR_C__TF)
MQ$B%P'3"28GE3(GGZ.CZ__](A<`/A*\```"`>!,N2(U8$W4-@'L!`'3?#Q^`
M`````(!X$RX/A*8```!(B>_HUOC__TB)WTF)QNC+^/__08U\!@)(8__HWOG_
M_TF)V4F)Z+X!````28G&2(G',<!(Q\+_____2(T-H3<``.@H^___OP$```!,
MB>I,B?;H*/C__TR)]X/X_W00BT0D&"4`\```/0!```!T6.B[]___3(GWZ)/W
M__],B>?H._K__TB%P`^%4____V:03(GGZ,CX__](B>_H,/C__^GJ_O__#Q\`
M@'L!+@^%4/___X![`@`/A!3____I0?___P\?@`````#HD_[__^NFZ!SX__]F
M9BX/'X0``````)!52(G^2(G]OP$```!(@>R@````9$B+!"4H````2(F$))@`
M```QP$B)XN@"^O__A<!U-HM4)!B!X@#P``"!^@!```!T"('Z`*```'4>O@(`
M``!(B>_HE_G__X7`#Y3`#[;`ZP</'T0``#'`2(N,))@```!D2"L,)2@```!U
M"4B!Q*````!=P^B%]___#Q]$``!52(G]Z&?W__](C50%_T@YU7(6Z9$````/
M'X0``````$B#Z@%(.=5T)8`Z+W3R2#G5<W9(@^H!2#G5=!(/'T``@#HO="A(
M@^H!2#G5=?*`?0`O=%Q(C3TA-@``7>E_^?__#Q^``````(`Z+W4)2(/J`4@Y
MU7+R2"GJ,<!(C4H"2('Y`!```'<?2(/"`;D`$```2(GN2(T]598``.A0^/__
M2(T%298``%W#2#G5=;_KGDB-/<,U``!=Z2/Y__\/'P!!5[K_#P``059!54%4
M28GT54B)_4B-/:,U``!(@>P0$```9$B+!"4H````2(F$)`@0```QP$F)Y4R)
M[NCP]?__A<!^=(U0_T2+/8*5``!,8_)"@#PT`'58A=)T8TR)\KXO````3(GO
MZ/3V__](A<!T3D2)_^A']___3(GQ3(GJ2(GN2(G'Z#;X__](BX0D"!```&1(
M*P0E*````'4Z2('$$!```%U!7$%=05Y!7\-FD$QC\.NG#Q\`1(L]$94``$2)
M_^CY]O__3(GB2(GN2(G'Z"OV___KL^CD]?__#Q]``$%7059!54%454B)]5-(
MB?M(@^P89$B+!"4H````2(E$)`@QP#'`@#X]#Y3`2`'%2(GOZ)GU__](C70D
M!$B)WTF)Q#'`Z#?[__](A<`/A`8!``!(B<=)B<7H<_7__TDYQ`^&T@```$QC
M="0$2<'F`P^V`X3`#X2>`0``/#T/A)8!``!(B=@/'P`/ME`!2(/``832=`6`
M^CUU[T@IV$B82HU\(`),`S5FE```Z$'V__])B09(A<!T6DB+!5*4``!(8U0D
M!$B-2P%(BQ30#[8#B`*$P'0A/#UU#.L;9@\?1```A,!T$0^V`4B#P@%(@\$!
MB`(\/77KQ@(],<!F#Q]$```/MDP%`(A,`@%(@\`!A,EU[TB+1"0(9$@K!"4H
M````#X4'`0``2(/$&%M=05Q!74%>05_##Q]``#'`9@\?1```#[94!0!!B%0%
M`$B#P`&$TG7NZ[T/'T``3(L]L9,``$F#/P`/A+8```!,B?A%,>V02(/`"$2)
MZD&#Q0%(@S@`=>^-<@-(8_9(P>8#BP6_HP``A<!U6\<%L:,```$```!(B??H
M2?7__TB%P`^$8?___TUC]4R)_DB)QTG!Y@-,B?+HV_7__TB)!423``!(B<%!
MC44!2)A(QP3!`````$2);"0$Z8C^__]F#Q^$``````!,B?_HB/7__TB)!1&3
M``!(B<%(A<`/A`;___]-8_5)P>8#Z[L/'T``,<#I?_[__[X0````13'MZ5__
M___HK_/__V9F+@\?A```````#Q]``$B#[`B+/::2``#HD?3__XL]FY(``.B&
M]/__2(L5-Y(``$B-#<AP``!(C35^,@``2(G'Z*GT__^+/7.2``#H7O3__TR-
M!?(S``!%,<E(C16]$0``2(G'3(G!2(TU:3(``$B#Q`CIQ_3__P\?@`````!(
M@^P(BSTVD@``Z"'T__](BQ72D0``2(/$"$B-#5]P``!(B<=(C342,@``Z4#T
M__]!5%532('L("```&1(BP0E*````$B)A"08(```,<!(B>5,C:0D$!```.A2
M\O__3(T-U#$``+H!$```2(GO08G`2(T-]S$``+X!````,<#H+?7__[H`$```
M3(GF2(GOZ`WR__]%,<"%P'@NC7@!2(G#2&/_Z)CS__])B<!(A<!T&$ACVTR)
MYDB)QTB)VNA/\___Q@08`$F)P$B+A"08(```9$@K!"4H````=0](@<0@(```
M3(G`6UU!7,/H0?+__Y#I.____V9F+@\?A```````05=!5D%528GU05152(G]
M2(T]9#$``%-(@>RX$```9$B+!"4H````2(F$)*@0```QP$B-="0,Z)7W__^^
M+P```$B)[TB)P^@%\O__2(7`=$`QP$B)[DB-/2<Q``#H[_O__TB)Z$B+G"2H
M$```9$@K'"4H````#X6"`0``2('$N!```%M=05Q!74%>05_##Q\`2(GOZ(CQ
M__](C37Q,```3(GO08G$Z';S__])B<9(A<!TGD&`/@!,C2UM,```#X3>````
M#Q]$``!(A=MT$TR)]DB)W^@8\O__A<`/A)T```!,B??H./'__XU0_XG!2&/"
M3`'P@#@O=1L/'X0``````(G1@^H!Q@``2&/"3`'P@#@O=.U"C40A`3W_#P``
M#X\M____38GPN@`0``"^`0```#'`3(V\)*````!(@^P(2(T-03$``%5,C0W?
M+P``3(G_Z%OS__](C50D($R)_K\!````Z%GP__]:687`=1"+1"0H)0#P```]
M`(```'132(TU##```#'_Z)7R__])B<9(A<`/A+G^__]!@#X`#X4G____2(7;
M=`6`.RYT%4V)[KD!````Z5O___\/'X0``````(![`0!TM^OC#Q^$``````"^
M`0```$R)_^@S\O__A<!UG$R)_DB-/9@O``#H8/K__TR)_^B8\O__Z6?^___H
M+O#__V9F+@\?A```````#Q\`#[8'28GXA,!T%V8/'T0``$B#QP$\+P^V!TP/
M1,>$P'7O3(G`PV9F+@\?A```````2(7_=`N`/P!T!NEA^/__D$B-/=,N``#I
M-/+__P\?0`!54TB-'2DO``!(@^Q(9@]O!1MM``!D2(L$)2@```!(B40D.#'`
M,<!(C6PD#`\11"009@]O!0=M``!FB40D,`\11"0@#Q]$```QP$B)[DB)W^@;
M]?__2(7`=#Y(8U0D#$B+!9J.``!(C0302(M0"$B)$$B%TG329BX/'X0`````
M`$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B-'9PN``"0,<!(B>Y(B=_HP_3_
M_TB%P'0V2&-4)`Q(BP5"C@``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(
MB1!(A=)U\.N^9@\?1```2(T=5"X``)`QP$B)[DB)W^AS]/__2(7`=#9(8U0D
M#$B+!?*-``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF
M#Q]$``!(C1T-+@``D#'`2(GN2(G?Z"/T__](A<!T-DAC5"0,2(L%HHT``$B-
M!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-'<0M
M``"0,<!(B>Y(B=_HT_/__TB%P'0V2&-4)`Q(BP52C0``2(T$T$B+4`A(B1!(
MA=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(T=A"T``)`QP$B)[DB)
MW^B#\___2(7`=#9(8U0D#$B+!0*-``!(C0302(M0"$B)$$B%TG329I!(BU`0
M2(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1WK+```D#'`2(GN2(G?Z#/S__](A<!T
M-DAC5"0,2(L%LHP``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72
M=?#KOF8/'T0``$B-'?`L``"0,<!(B>Y(B=_HX_+__TB%P'0V2&-4)`Q(BP5B
MC```2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```
M2(T=JBP``)`QP$B)[DB)W^B3\O__2(7`=#9(8U0D#$B+!1*,``!(C0302(M0
M"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1UD+```D#'`
M2(GN2(G?Z$/R__](A<!T-DAC5"0,2(L%PHL``$B-!-!(BU`(2(D02(72=-)F
MD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-';0K``"0,<!(B>Y(B=_H\_'_
M_TB%P'0V2&-4)`Q(BP5RBP``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(
MB1!(A=)U\.N^9@\?1```2(GN2(T]RRL``.BI\?__2(G&2(7`=`Y(C3VC*P``
M,<#H$_;__TB)[DB-/;<K```QP.B"\?__2(G&2(7`=`Y(C3VS*P``,<#H[/7_
M_TB)[DB-/:TK```QP.A;\?__2(G&2(7`=#I(C3WV*@``,<#HQ?7__S'`2(TU
MLRL``$B-/1@K``#HL/7__TB+1"0X9$@K!"4H````=5%(@\1(6UW#2(GN2(T]
M:BL``#'`Z`CQ__](B<9(A<!T$$B-/?@J```QP.AR]?__ZZM(N%!!4E]#3$5!
M2#E$)"%UFF:!?"0I3CUUD4B-="0KZ\_H*NO__V8N#Q^$``````!(@^P89$B+
M!"4H````2(E$)`B+!0B*``"#^/]T&TB+?"0(9$@K/"4H````=4)(@\08PV8/
M'T0``$B-="0$2(T]>RH``#'`Z'7P__](B<(QP$B%TG02#[82@/HP#Y7!,<"$
MT@^5P"'(B06SB0``ZZ[HK.K__V9F+@\?A```````D$B#[`CHI^K__XG'Z%#J
M__](A<!T`TB+`$B#Q`C##Q\`05152(G]2(T]C"H``%-(@^P09$B+!"4H````
M2(E$)`@QP$B-="0$Z/3O__](A<!T"(`X`$B)PW4W2(M$)`AD2"L$)2@````/
MA;D```!(B>Y(@\002(T]/BH``#'`6UU!7.DZ]/__9BX/'X0``````$B)[DB)
MQ^AU[/__2(7`="!(BT0D"&1(*P0E*````'5V2(/$$%M=05S##Q^``````$B)
M[^C(Z?__2(G?28G$Z+WI__])C7P$`NC3ZO__2(/L"$F)Z+X!````4TC'PO__
M__](B<=)B<1,C0T"*0``2(T-\2D``#'`Z!3L__]86DB+1"0(9$@K!"4H````
M=0A,B>;I2O___^AUZ?__#Q]$``!!5T%6055)B?U(C3VJ*```05154TB![(B!
M``!D2(L$)2@```!(B80D>($``$B-!7(I``!,C60D'$C'1"0P`````$C'A"2(
M`````````$R)YDC'1"10`````$B)1"0@2(T%!2@``$B)1"0H2(T%V"@``$B)
M1"1H2(T%+2D``$B)1"1P2(T%W2@``$B)1"1X2(T%'2D``$B)A"2`````2(T%
M$BD``$B)1"1(,<#H8.[__TB%P'0,@#@`2(G%#X6/!```Z+KH__^)Q^ACZ/__
M2(7`#X3:`P``2(LH2(7M#X3.`P``2(GOZ';H__](C7P``>B,Z?__1`^V10!(
MB<-%A,!T.DF)WTR--;0H```/'T0``$R)_TR)\4C'PO____\QP+X!````2(/%
M`4F#QP+HO^K__T0/MD4`183`==5,C70D8$B-/0DH``#K&`\?@`````!)BWX(
M28/&"$B%_P^$+P$``$R)YC'`Z*7M__](B<5(A<!TW8`X`'382(G'Z.#O__^%
MP'3,2(GOZ$3J__])B<=(A<`/A/@````/'X0``````$R)_^BXY___2(G?2(G%
MZ*WG__]$C;0%!`0``$UC]DR)]^BZZ/__4TV)^$R-#9LF``!(B<5(C07R)P``
MO@$```!(Q\+_____4$B-#=4G``!(B>\QP.CWZ?__2(GOOL`!``#HRN;__U]!
M6(/X_W42Z(WF__]$BPA!@_D1#X4$`P``2(V4))````!(B>Z_`0```.A;Z?__
MB<.%P`^$L0```$F+30!(BSUVA@``28GH,<!(C14B*```O@$```!%,?;H7>G_
M_TB+A"1X@0``9$@K!"4H````#X56!0``2('$B($``$R)\%M=05Q!74%>05_#
MD$B+;"0@13'VZQ-F#Q]$``!)8\9(BVS$($B%[70[@'T``'0U2(GO08/&`>BA
M[O__A<!TW4B)[^@%Z?__28G'2(7`#X7)_O__26/&2(MLQ"!(A>UUR0\?0`!%
M,?_IL/[__XN$)*@````E`/```#T`0```#X4X____1(N\)*P```#H;.;__T$Y
MQP^%(O___XN$)*@````E_P$``#W``0``#X4+____3(GWZ$3G__](C3U1)@``
M3(GF28G&,<#HP.O__TB)QTB%P`^$-`(``.AOZ/__28M]`$B)QNC3\___28G'
M2(7`#X07`@``3(G_Z-_E__^#^`-^.DACT+D%````2(T]/28``$F-=!?\\Z8/
ME\*`V@"$TG4:@_@$#X1U`P``@^@%2)A!@#P'+P^$90,``)"+!:J$``"#^/\/
MA!D#``"%P`^$S`$``$B--:DE``!(C3TJ)0``,<#HI.___TR-)1@F``!,C2UR
M)```Z/'D__]!5$F)Z+X!````4$C'PO____],B?<QP$R-#4\D``!(C0W')0``
MZ,?G__]86NM$#Q\`Z&OD__^#.!%U2>BQY/__@\,!2(/L"$V)Z4%428GH2(T-
MI"4``$R)]U-(Q\+_____O@$```!0,<#H@^?__TB#Q""^P`$``$R)]^A2Y/__
M@_C_=*U(B>_H!>3__TR)]DB-/24D```QP.CT[O__3(GWZ$SZ___INOW__P\?
M@``````QVTB-/>`D``#K$@\?1```2&/#2(M\Q$!(A?]T.$R)YC'`@\,!Z#;J
M__](A<!TX8`X`'3<2(G'Z.3F__](B<5(A<`/A>K[__](8\-(BWS$0$B%_W7(
MOPT```!(C2V-)```Z&KE__]!N%,```!(B</IW?O__TF+30!(BSV1@P``28GH
M,<!(C17])```O@$```!%,?;H>.;__^D6_?__#Q\`2(G'Z)CY__](BX0D>($`
M`&1(*P0E*`````^%80(``$B!Q(B!``!(B>];74%<05U!7D%?Z4CF__\/'X0`
M`````$V+?0#IX/W__\<%S8(````````Q]DR)_S'`Z''E__]!B<2%P`^$'?[_
M_[H"````2,?&[O___XG'Z./E__](C9PD<`$``+H&````1(GG2(G>Z#OD__^`
MO"1P`0```'4.@+PD<0$``$,/A&D!```QTC'V1(GGZ*?E__\QP.C0&P``28G%
MZQ`/'P")PDB)WDR)[^@;'```N@"```!(B=Y$B>?HZ^/__X7`?]]$B>=,C;PD
M(`$``$R-)70C``#H@./__TR)[DR)_TR-K"1H`0``Z'T=``!(C80D0`$``$B)
M1"0(2(G##Q]$``!%#[8'2(G?3(GAO@$```!(Q\+_____,<!(@\,"28/'`>A3
MY?__23G===9(C05B(P``QH0D:`$```!0_W0D$$B-#1\C``!)B>A,B?<QP+X!
M````3(T-FR$``$C'PO_____H$^7__UE>Z9_]__\/'T``,<!,B>9(C3T;(@``
MZ!?H__](A<`/A)?^__\/M@"$P`^$C/[__SPP#X2$_O__QP51@0```0```.FS
M_/__38MM"$V%[0^$C_S__TR)[^@GXO__2(/X`P^&??S__TF-=`7\N04```!(
MC3V#(@``\Z8/E\`<`(3`30]$_>E:_/__@+PD<@$``$$/A8G^__^`O"1S`0``
M0P^%>_[__X"\)'0!``!(#X5M_O__@+PD=0$``$4/A5_^__^Z`@```$C'QL;_
M__]$B>?H_N/__[HI````2(G>1(GGZ%[B__](C05"(@``4%/IYO[__^B;X?__
M9F8N#Q^$``````!!54%454B#[!"+/9&```!D2(L$)2@```!(B40D"#'`Z&SB
M__^+/7:```!(B<7H7N+__P^VE;@```!(C6PD!$B-/<X@``!(B>Z(D+D````Q
MP.C;YO__2(7`=`F`.#$/A+4!```QP.A6\?__BSTP@```Z!OB__^Y`P```+H!
M````2(TUI"$``$B)Q^C2X?__28G$2(7`=#A(BT`0BST`@```3(LHZ.CA__](
MC15](0``2(G'3(GNZ!;A__])BT0D$$R+($'V1"0.0`^%D@$``(L]S'\``.BW
MX?__N0,```"Z`0```$B--4<A``!(B<?H;N'__TF)Q$B%P'0^2(GN2(T]WQ\`
M`#'`Z"7F__])B<5(A<`/A!D!``!)BT0D$(L]?G\``$R+(.AFX?__3(GJ2(G'
M3(GFZ)C@__^+/6)_``#H3>'__[H!````2(TUY"```$B)Q^A9X?__BSU#?P``
M28G$Z"OA__],B>9(C179(```2(G'Z%G@__^+/2-_``#H#N'__TB)[DB-/4X?
M``#&@+D`````,<#HEN7__TB)!6>/``!)B<1(A<!T/[[``0``3(GGZ#K?__^-
M4`&#^@%V"8/X$0^%M````$B+1"0(9$@K!"4H````#X6]````2(/$$%U!7$%=
MPP\?`$B+/2&/``#H+/;__TB)!0V/``!)B<1(A<!UIDB-/>8@```QP.BOX/__
M#Q^``````(!X`0`/A$C^___I//[__V8/'X0``````$B+!=F.``"+/6-^``!,
MBRA)BT0D$$R+(.A#X/__3(GN3(GGZ'CH___IV_[__P\?`(L].GX``.@EX/__
M3(GF2(G'Z'K@___I4_[__XG!2(L%C(X``$R)XDB-/8H@``!(BS`QP.@HX/__
MZ//>__\/'P!!5%5(B?U32(/L$&1(BP0E*````$B)1"0(,<!(A?\/A+P```"`
M/P`/A+,```#H/N?__P^V$$B)PX32=!8/'T``2(/``8#Z+P^V$$@/1-B$TG7N
MBP68?0``2(7M00^5Q(/X_P^$D````(7`#Y7`02'$183D=2-(BT0D"&1(*P0E
M*`````^%L````$B#Q!!;74%<PV8/'T0``(!]``!TU[D$````2(T]HQX``$B)
MWO.F#Y?`'`"$P'6]2(M$)`AD2"L$)2@```!U<4B#Q!!(B>];74%<Z8CD__\/
M'X0``````$B-/0,=``#H9.#__^E!____#Q^``````#'`2(UT)`1(C3V)'0``
MZ(7C__](A<!T"P^V`(3`=`0\,'4/QP7+?````````.E+____QP6\?````0``
M`.DW____Z++=__]FD$%73(U/.$%6055!5%532('LF`(``&1(BP0E*````$B)
MA"2(`@``,<!(B>),C90D@````$F)T&8N#Q^$``````!!BP%)BS%)@\`028/!
M"`_(B<!(B?%)B4#P2(GP2,'I($C!Z"A(P>XX)0#_``!("?!(B<Y(P>$(2,'F
M&('A``#_`(GV2`GP2`G(28E`^$TYT'6N2(VR``(```\?@`````!(BT)H2#-"
M0$B#P@A(,T((2#-"^$B-#`!(P>@?2`G(@^#_2(E">$@Y\G753(L/3(M?$$B+
M=R!(BU\83(G(3(G*2(MO"$C!ZAM(P>`%2`G0`P0DC90PF7F"6DR)V$B+="0(
M2#'82"'H2(VT,YEY@EI(,=A$C10"2(GJ2(GH2,'H`DC!XAY-B=!("<),B=A)
MP>@;B=%(,<A,(<A,,=A(`?!,B=9(P>8%3`G&1(TT,$R)SDR)R$C!YAY(P>@"
M38GP2`GP2(MT)!!)P>@;2#'"08G%3"'228VT,YEY@EI(,<I(`?),B?9(P>8%
M3`G&1(T$,DR)UDG!Z@)(BU0D&$C!YAY,"=9(C901F7F"6DR)P4@Q\$&)]$PA
M\$PQZ$C!Z1M(`=!,B<)(P>(%2`G*3(GQ2<'N`DC!X1Y$C1002(GP2(M4)"!,
M"?%,B=9(,<A)C905F7F"6DC![AM!B<Y,(<!,,>!(`=!,B=)(P>(%2`GR1(TL
M$$R)PDG!Z`)(BT0D*$C!XAY,B>Y,"<))C80$F7F"6DC![AM(,=%!B=!,(=%,
M,?%(`<%,B>A(P>`%2`GP1(TD`4R)T$G!Z@)(BTPD,$C!X!Y,B>9,"=!)C8P.
MF7F"6D@QPD&)PDPAZDPQPD@!RDR)X4C!X05(P>X;2`GQ3(GN2<'M`DC!YAY$
MC30*2(M4)#A,">Y,B?%(,?!)C900F7F"6DC!Z1M!B?5,(>!,,=!(`=!,B?)(
MP>(%2`G*3(GA2<'L`DC!X1Y$C0002(GP2(M4)$!,">%,B<9(,<A)C902F7F"
M6DC![AM!B<Q,(?!,,>A(`=!,B<)(P>(%2`GR1(T4$$R)\DG![@)(BT0D2$C!
MXAY,B=9,"?))C80%F7F"6DC![AM(,=%!B=9,(<%,,>%(`<%,B=!(P>`%2`GP
M1(TL`4R)P$G!Z`)(BTPD4$C!X!Y,B>Y,"<!)C8P,F7F"6DC![AM(,<)!B<!,
M(=),,?)(`<I,B>E(P>$%2`GQ3(G62<'J`DC!YAY$C20*2(M4)%A,"=9,B>%(
M,?!)C906F7F"6DC!Z1M!B?),(>A,,<!(`=!,B>)(P>(%2`G*3(GI2<'M`DC!
MX1Y$C3002(GP2(M4)&!,">E,B?9(,<A)C900F7F"6DC![AM!B<U,(>!,,=!(
M`=!,B?)(P>(%2`GR1(T$$$R)XDB+1"1H2,'B'DG![`),B<9,">))C80"F7F"
M6DC![AM(,=%!B=1,(?%,,>E(`<%,B<!(P>`%2`GP1(T4`4R)\$G![@)(BTPD
M<$C!X!Y,B=9,"?!)C8P-F7F"6DC![AM(,<)!B<9,(<),,>)(`<I,B=%(P>$%
M2`GQ3(G&2<'H`DC!YAY$C2P*2(M4)'A,"<9,B>E(,?!)C904F7F"6DC!Z1M!
MB?!,(=!,,?!(`=!,B>I(P>(%2`G*3(G12<'J`DC!X1Y$C2002(GP2(N4)(``
M``!,"=%,B>9(,<A)C906F7F"6DC![AM!B<I,(>A,,<!(`=!,B>)(P>(%2`GR
M1(TT$$R)ZDG![0)(BX0DB````$C!XAY,B?9,">I)C80`F7F"6DC![AM(,=%!
MB=5,(>%,,=%(`<%,B?!(P>`%2`GP1(T$`4R)X$G![`)(BXPDD````$C!X!Y,
M">!)C8P*F7F"6DV)PD@QPDG!ZAN)QDPA\DPQZD@!RDR)P4C!X05,"=%-B?))
MP>X"2<'B'HG)30GR2`'*2(N,))@```!,,=!!B=1,(<!)C8P-F7F"6DV)Y4@Q
M\$G![1M(`<A,B>%(P>$%3`GIB<E(`<A,B<%)P>@"2,'A'D&)Q4P)P4V)T$6)
MTDP#E"2H````23'(1#'"3(N$)*````!.C80&H>O9;DR)[DD!T$R)ZDC![AM(
MP>(%2`GRB=))`=!,B>))P>P"2,'B'D2)QDP)XDF)S(G)2`.,)+````!),=1$
M,>!)B?1-C90"H>O9;DB)\$G![!M(P>`%3`G@B<!)`<),B>A)P>T"2,'@'D6)
MU$P)Z$F)U8G223'%13'H38GE2`.4)+@```!.C80!H>O9;DR)X4G![1M(P>$%
M3`GIB<E,`<%)B?!(P>X"2<'@'D&)S4D)\$B)QHG`2`.$),````!,,<9!,?)*
MC;02H>O9;DR)ZDV)ZDG!ZAM(P>(%3`G2B=)(`?),B>9)P>P"2,'F'D&)TDP)
MYDV)Q$6)P$P#A"3(````23'T1#'A38G42(V,"*'KV6Y,B=!)P>P;2,'@!4P)
MX(G`2`'(3(GI2<'M`DC!X1Y!B<1,">E)B?6)]DDQS40QZDV)Y4V-A!"AZ]EN
M3(GB2,'B!4G![1M(`[0DT````$P)ZHG220'03(G22<'J`DC!XAY%B<5,"=))
MB<J)R4@#C"38````23'21#'038GJ2(VT!J'KV6Y,B>A)P>H;2,'@!4P)T(G`
M2`'&3(G@2<'L`DC!X!Y!B?),">!)B=2)TD@#E"3@````23'$13'@38G43HV$
M`:'KV6Y,B=%)P>P;2,'A!4P)X8G)3`'!38GH2<'M`DG!X!Y!B<Q-">A)B<6)
MP$TQQ40Q[DV)Y4B-M#*AZ]EN3(GB2<'M&TC!X@5,">J)TD@!\DR)UDG!Z@)(
M`X0DZ````$C!YAY!B=5,"=9-B<)%B<!,`X0D\````$DQ\D0QT4V)ZDB-C`BA
MZ]EN3(GH2<'J&TC!X`5,"=")P$@!R$R)X4G![`)(P>$>08G"3`GA28GTB?9(
M`[0D^````$DQS$0QXDV)U$V-A!"AZ]EN3(G22<'L&TC!X@5,">*)TDD!T$R)
MZDG![0)(P>(>18G$3`GJ28G-B<E),=5$,>A-B>5(C;0&H>O9;DR)X$G![1M(
MP>`%3`GHB<!(`<9,B=!(P>`>2<'J`D&)]4@#C"0``0``3`G028G2B=)(`Y0D
M"`$``$DQPD4QT$V)ZDZ-A`&AZ]EN3(GI2<'J&TC!X05,"=&)R4P!P4V)X$G!
M[`))P>`>08G*30G@28G$B<!(`X0D$`$``$TQQ$0QYDV)U$B-M#*AZ]EN3(G2
M2<'L&TC!X@5,">*)TD@!\DR)[DG![0)(P>8>08G43`GN38G%18G`23'U1#'I
M38GE2(V,"*'KV6Y,B>!)P>T;2,'@!4P)Z(G`2`'(3(G12<'J`DC!X1Y!B<5,
M"=%)B?),`X0D&`$``(GV23'*2`.T)"`!``!$,=)-C;00H>O9;DR)ZDV)Z$G!
MZ!M(P>(%3`G"28G(B<E(`XPD*`$``(G220'63(GB2<'L`DC!XAY%B?),">))
M,=!$,<!,C:0&H>O9;DR)T$R)UDC![AM(P>`%2`GP2(G6B=)(`Y0D,`$``(G`
M20'$3(GH2<'M`DC!X!Y%B>!,">A(,<9!,?9,B<9.C:PQH>O9;DR)P4C![AM(
MP>$%2`GQB<E)`<U,B=%)P>H"2,'A'D2)[DP)T4F)PHG`23'*13'42`.$)#@!
M``!.C90BH>O9;DB)\DF)]$G![!M(P>(%3`GB38G$2<'H`DG!Y!Y!`=)-"<1)
MB<B)R4TQX$2)XD4QQ4Z-A"BAZ]EN3(G038G52<'M&TC!X`5,">A,BZPD0`$`
M`$6--`!)B?!(P>X"3(G@2<'@'DD)\$2)QDP)P$PAT$DA]$D)Q+C<O!N/20'%
M3`'I38GU3`'A38GT2<'M&TG!Y`5-">Q!`<Q,B=%)P>H"2,'A'DP)T4D)R$F)
MS4&)RDTA\$DA]4T)Z$R+K"1(`0``20'%3`'J38GE20'03(GB2<'M&TC!X@5,
M">I%C2P03(GR2<'N`DC!XAY,"?))B<Y!B=!)"=9-(>9,(<%,"?%,B[0D4`$`
M`$D!QDP!]DV)[D@!\4R)[DG![AM(P>8%3`GV1(TT,4R)YDG![`)(P>8>3`GF
M2`GR28GTB?%-(<1,(>I,">),BZ0D6`$``$D!Q$T!XDV)]$P!TDV)\DG!X@5)
MP>P;30GB1HTD$DV)ZDG![0))P>(>30GJ28GU1(G230G532'U2"'63`GN3(NL
M)&`!``!)`<5-`>A-B>5,`<9-B>!)P>T;2<'@!4T)Z$:-+`9-B?!)P>X"2<'@
M'DT)\$T)PDV)QD2)QDDAUDTAXDT)\DR+M"1H`0``20'&3`'Q38GN20'*3(GI
M2<'N&TC!X05,"?%%C30*3(GA2<'L`DC!X1Y,">%-B<1)"<Q!B<I-(>Q-(=!-
M">!,BZ0D<`$``$D!Q$P!XDV)]$D!T$R)\DG![!M(P>(%3`GB18TD$$R)ZDG!
M[0)(P>(>3`GJ2`G128G508G032'53"'Q3`GI3(NL)'@!``!)`<5,`>Y-B>5(
M`?%,B>9)P>T;2,'F!4P)[D2-+#%,B?9)P>X"2,'F'DP)]DF)UHGQ20GV32'F
M2"'*3`GR3(NT)(`!``!)`<9-`?)-B>Y,`=)-B>I)P>X;2<'B!4T)\D:--!)-
MB>))P>P"2<'B'DT)XDP)UDV)U$2)TDDAS$PA[DP)YDR+I"2(`0``20'$30'@
M38GT3`'&38GP2<'L&TG!X`5-">!&C20&38GH2<'M`DG!X!Y-">A-B=5$B<9-
M"<5-(?5)(?)-">I,BZPDD`$``$D!Q4P!Z4V)Y4D!RDR)X4G![1M(P>$%3`GI
M18TL"DR)\4G![@)(P>$>3`GQ20G(28G.08G*22'V32'@30GP3(NT))@!``!)
M`<9,`?)-B>Y)`=!,B>I)P>X;2,'B!4P)\D6--!!,B>))P>P"2,'B'DP)XDF)
MS$&)T$D)U$TA[$PAP4P)X4R+I"2@`0``20'$3`'F38GT2`'Q3(GV2<'L&TC!
MY@5,">9$C20Q3(GN2<'M`DC!YAY,">Y("?))B?6)\4TAQ4PA\DP)ZDR+K"2H
M`0``20'%30'J38GE3`'238GB2<'M&TG!X@5-">I&C2P238GR2<'N`DG!XAY-
M"?))B?9$B=)-"=9-(>9((=9,"?9,B[0DL`$``$D!QDT!\$V)[DP!QDV)Z$G!
M[AM)P>`%30GP1HTT!DV)X$G![`))P>`>30G@30G"38G$1(G&22'432'J30GB
M3(ND)+@!``!)`<1,`>%-B?1)`<I,B?%)P>P;2,'A!4P)X46-)`I,B>E(P>$>
M2<'M`DP)Z4V)Q4&)RDD)S4TA]4TAT$T)Z$R+K"3``0``20'%3`'J38GE20'0
M3(GB2<'M&TC!X@5,">I%C2P03(GR2<'N`DC!XAY,"?)("=%)B=!!B==-(=!,
M(>%,"<%,BX0DR`$``$D!P$P!QDV)Z$@!\4R)[DG!Z!M(P>8%3`G&1(T$,4R)
MYDG![`)(B=%(P>8>3`GF08GT2`GQ3"'I3"'B2`G*2(N,)-`!``!(`<%(`X0D
MV`$``$D!RDR)P4D!QTP!TDV)PDC!X05)P>H;3`G1B<E(`<I,B>E)P>T"2,'A
M'D&)TDP)Z4R)T$@)SDF)S4C!X`5!B<Y-(>5,(<9,">Y-B=5)P>T;3`'^3`GH
MB<!(`<9,B<!)P>@"2,'@'D&)]4D)P+C6P6+*3#'!,<I(BXPDX`$``$@!P4P!
MX4V)[$@!T4R)ZDG![!M(P>(%3`GBB=)(`=%,B=))P>H"2,'B'D&)S$D)TDR)
MPD6)P$PQTC'62(N4).@!``!(`<))`=9,B>),`?9-B>9(P>(%2<'N&TP)\HG2
M3(TT%DR)ZDG![0),B=9(P>(>18GW18G220G52(N4)/`!``!,,>Y(`<(Q\4R)
M_DP!PDC![AM(`=%,B?I(P>(%2`GR2(NT)/@!``")TD@!T4R)XD@!QDG![`)(
MP>(>3`'638GJ08G(3`GB38G$18GM23'213'63HT4-DR)QDC!Y@5)P>P;3`GF
MB?9)`?),B?Y)P>\"2,'F'D6)U$D)]TB+M"0``@``2`'&3`'N28G5B=)-,?U$
M,>E,C2P.3(GA3(GF2,'N&TC!X05("?%,B<9)P>@"B<E(P>8>20'-2(N,)`@"
M``!,"<9-B?A),?!%B>Y%B?](`<%%,<)(`<I,B?%.C0023(GR2,'I&TC!X@5(
M"<I(B?&)]HG220'03(GB2<'L`DC!XAY%B<))"=1(BY0D$`(``$PQX4@!PD$Q
MS4R)T4P!^DD!U4R)TDC!Z1M(P>(%2`G*3(GQ2<'N`HG22,'A'DD!U4B+E"08
M`@``3`GQ18GO2`'"2`'R3(GF18GD2#'.03'P3(G^20'03(GZ2,'N&TC!X@5(
M"?*)TDD!T$R)TDG!Z@)(P>(>18G&20G22(N4)"`"``!,B?9(P>X;2`'"3`'B
M28G,B<E-,=1%,>5.C20J3(GR2,'B!4@)\DB+M"0H`@``B=))`=1,B?I(`<9)
MP>\"2,'B'D6)Y4P)^D@!\4R)UD6)TD@QUD$Q\$R)[DD!R$R)Z4C![AM(P>$%
M2`GQB<E)`<A,B?%)P>X"2,'A'D6)QTD)SDB+C"0P`@``3(G^2,'N&T@!P4P!
MT4F)THG233'R13'43HT4(4R)^4C!X05("?%,B>Y)P>T"B<E(P>8>20'*2(N,
M)#@"``!,">Y%B=1(`<%(`<I,B?%%B?9(,?%!,<A,B>%)`=!,B>)(P>D;2,'B
M!4@)RDB)\8GVB=))`=!,B?I(P>(>2<'O`D6)Q4D)UTB+E"1``@``3#'Y2`'"
M03'*3(GI3`'R2,'I&TD!TDR)ZDC!X@5("<I,B>%)P>P"B=)(P>$>20'22(N4
M)$@"``!,">%%B?Q%B=9(`<)(`?),B?Y(,<Y!,?!*C30"3(GR38GP2<'H&TC!
MX@5,"<*)TD@!UDR)ZDG![0)(P>(>08GP20G52(N4)%`"``!(`<),`>))B<R)
MR4TQ[$4QXDZ-)!),B<)-B<))P>H;2,'B!4P)THG220'43(GR2<'N`DC!XAY%
MB>),"?),B[0D6`(``$D!QDP!\4V)[D6)[4DQUD0Q]DV)UD@!SDR)T4G![AM(
MP>$%3`GQB<E(`<Y,B<%)P>@"2,'A'D&)]DD)R$B+C"1@`@``2`'!20'-2(G1
MB=),,<%!,<Q+C4PE`$V)]$V)]4G![1M)P>0%30GL38G52<'J`DG!Y1Y%B>1-
M">I,BZPD:`(``$P!X4&)S$D!Q4P!ZDV)Q46)P$TQU40Q[DR-+#),B>),B>9(
MP>(%2,'N&T@)\HG220'53(GR2<'N`DC!XAY$B>Y)"=9(BY0D<`(``$@!PD@#
MA"1X`@``3`'"38G033'P1#'!28GP2`'*2(GQ2<'H&TC!X05,"<%%B=`!T4R)
MXDG![`)(P>(>20G42HT4"$B)R$D!T$R)\DC!X`5$`>-,,>)(B5\803'52XT4
M*$F)R`'I2<'H&TB)3PA,"<`!T$B)!TB)\$C![@)(P>`>2`G&00'S1`-W($R)
M7Q!,B7<@2(N$)(@"``!D2"L$)2@```!U$DB!Q)@"``!;74%<05U!7D%?P^B4
MQ___#Q]``$B#[`B_@````.B2R/__NHFKS>^Y_MRZF+[PX=+#2,<``2-%9TB)
M4`A(B4@02,=`&'94,A!(B7`@2,=`*`````!(QT`P`````,=`>`````!(@\0(
MPV9F+@\?A```````D$%72&/"059)B<9!54%428G\54B-;SA32(GS2(/L"$B+
M=RA(BU<PC0S&2#GQ2(E/*$B#T@!(P>@=2`'02(E',$AC1WB%P`^%[0```$&#
M_C\/CBL!``!!@^Y`18GW0<'O!D6-;P%)P>4&20'=#Q]$``#S#V\#3(GG2(/#
M0`\110#S#V]+T`\131#S#V]3X`\152#S#V];\`\173#HX>C__TPYZW7,0<'G
M!D4I_DECQDB#^`AR7$F+50!)B50D.$F+5`7X2(E4!?A(C54(2(/B^$@IU4DI
M[4@!Q4B#Y?A(@_T(<AA(@^7X,<!)BTP%`$B)#`)(@\`(2#GH<NY%B70D>$B#
MQ`A;74%<05U!7D%?PV:0J`1U=$B%P'3A00^V50!!B%0D.*@"=--!#[=4!?YF
MB50%_NO&#Q]``$&]0````$B-?`4`2(G>02G%13GN10].[DUC_4R)^NBUQO__
M08M$)'A$`>A!B40D>(/X0'623(GG12GN3`'[Z`7H___IR_[__TF)W>DC____
M08M5`$&)5"0X08M4!?R)5`7\Z5O___^0059,C78X055!5%5(B?532(M&*$B)
M^T2+9BA$BVXP2,'H`X/@/T$/S$$/S8U(`4B8QD0&.(!(8\%,`?"#^3@/CB0!
M``"^0````"G.=`\QTHG1@\(!Q@0(`#GR<O-(B>_H?.?__V8/[\`/$44X2<=&
M,`````!!#Q%&$$$/$48@1(EM<$B)[T2)973H4N?__TB+10!(B>](P>@8B`-(
MBT4`2,'H$(A#`4B+10!(P>@(B$,"2(M%`(A#`TB+10A(P>@8B$,$2(M%"$C!
MZ!"(0P5(BT4(2,'H"(A#!DB+10B(0P=(BT402,'H&(A#"$B+11!(P>@0B$,)
M2(M%$$C!Z`B(0PI(BT40B$,+2(M%&$C!Z!B(0PQ(BT482,'H$(A##4B+11A(
MP>@(B$,.2(M%&(A##TB+12!(P>@8B$,02(M%($C!Z!"(0Q%(BT4@2,'H"(A#
M$DB+12"(0Q-;74%<05U!7NE+P___#Q\`NC@````Q_RG*@_H(<DJ)T4C'````
M``!(QT0(^`````!(C4@(2(/A^$@IR`'"@^+X@_H(#X+=_O__@^+X,<")QH/`
M"$B)/#$YT'+SZ<;^__\/'X0``````/;"!'4CA=(/A+'^___&``#VP@(/A*7^
M__\QR6:)3!#^Z9G^__\/'P#'``````#'1!#\`````.F#_O__#Q]$``!!5TR-
M/4=>``!!5DF)UD%528GU051!B?Q52(TM.%X``%-,*?U(@^P(Z%/"__](P?T#
M=!LQVP\?`$R)\DR)[D2)YT'_%-](@\,!2#G==>I(@\0(6UU!7$%=05Y!7\,/
M'P##9BX/'X0```````\?1```2(L-$6(``.F4P___2(/L"$B#Q`C#````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"X`+P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O
M)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0
M051(`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R
M>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S
M=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K
M97(Z.E9%4E-)3TX`,2XP-3(`+64`+2T``````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ
M4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P
M87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*
M:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&
M25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@
M)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@
M)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE
M;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ
M<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["B10
M05)?34%'24,@/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O
M<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(
M+"`G/#IR87<G+"`D<')O9VYA;64@;W(@;&%S=#L*;7D@)&)U9CL*;7D@)'-I
M>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T
M.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*
M)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@)&-H
M=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E
M;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI
M;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K(%]&2"P@)&UA9VEC7W!O<RP@
M,#L*<F5A9"!?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?
M34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I
M*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O
M<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P.PIS
M965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T
M.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F
M*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0[
M"G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%
M(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N
M<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F
M=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[
M"FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N
M*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E
M>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S
M96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA
M;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD
M36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]
M/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U
M9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L
M92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM
M>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E
M='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B
M.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ
M;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE
M(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I
M.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*
M<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H
M+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)
M3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I
M;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E
M7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE
M;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D
M+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M
M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]
M"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N
M;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL
M(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY
M($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE
M7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ
M92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@
M,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@
M*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@
M)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P
M87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?
M<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2![
M"G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%2
M1U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?
M=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/
M0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP
M=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V
M86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P
M87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#([
M"GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L
M<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D
M,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2![
M"F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L
M;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C
M:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET
M7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R
M(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F
M:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M87(B73L*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@
M/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ
M7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>
M("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R
M96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@
M)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL
M97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R
M96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?
M1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@
M>PIR96%D(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D
M:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O
M<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*
M;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM
M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R
M(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE
M;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*3L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E
M<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]
M"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG
M.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E
M86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO
M861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB
M7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A8
M6"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*
M:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E
M('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1
M)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I
M.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\
M*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q
M(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*
M?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W
M<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL
M92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K
M:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@
M.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD
M968["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L;W-E
M("1F:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L
M("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N
M86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ
M8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N
M9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S
M("(D;F%M92)=*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P
M96X@;7D@)&9H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D[
M"F-L;W-E("1F:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE
M7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG
M=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC
M;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S
M(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E
M(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I
M<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H
M+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I
M(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?
M1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!
M4E]414U0?2)=*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S
M:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E
M<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E
M8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN
M97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD
M0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q
M6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B72D[
M"B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM
M;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*
M?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\
M("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@
M+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L
M(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*
M?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@
M1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR
M97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@
M=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*
M<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y
M;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E
M<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT
M;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(
M86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL
M:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I
M<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O
M7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A
M<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D
M<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A
M73L*<V5E:R`D9F@L("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L
M(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R
M.PIR96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM
M>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^
M:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92![
M"B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I
M9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D
M92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N
M;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA
M;64N)"0B.PIO<&5N(&UY("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I
M92!Q<5M#86XG="!W<FET92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@
M)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@
M:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE
M*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]
M"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P
M<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP
M871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@
M/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE
M9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F
M5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H
M;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[
M7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@
M96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2![
M"F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%
M35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%
M3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"
M04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q
M,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF
M("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R![
M"G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H
M(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?
M:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D
M+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I
M=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@
M=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*
M=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P
M87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I
M<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*
M=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET
M*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@
M:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET
M*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!P
M97)L>'-I+F,`````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`!&P,[!`$``!\```"0@?__4`$``!"%__]X`0``((7___0%```PA___(`$`
M`""(__^0`0``\(C__]P!``!PBO__(`(```"+__]$`@``P(O__VP"``"@C/__
ML`(``.".___\`@``4(___Q0#``"`C___+`,``$"0__]@`P``4)#__W0#``!@
MDO__U`,``)"2___H`P``L)+___P#``!@E___*`0``."7__]$!````)C__UP$
M```0F?__K`0``/"@__]\!0``D*/__[`%``#0I/__(`8``/"Z__]P!@``4+O_
M_X@&``#PO/__U`8``/"^__\8!P``4+___V`'``!@O___>`<````````4````
M``````%Z4@`!>!`!&PP'")`!!Q`4````'`````B&__\K```````````````4
M``````````%Z4@`!>!`!&PP'")`!```D````'````#B`__^``P````X01@X8
M2@\+=PB``#\:.RHS)"(`````%````$0```"0@___"```````````````2```
M`%P```"(AO__S0````!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=$
M#D`";`H..$0.,$$.*$(.($(.&$(.$$(."$D+`$````"H````#(?__W0!````
M0@X0C@)"#AB-`T(.((P$00XHA@5!#C"#!D<.T`%^"@XP00XH00X@0@X80@X0
M0@X(2PL`(````.P```!(B/__BP````!!#A"&`E(.L`$"<0H.$$$."$$+)```
M`!`!``"TB/__O0````!!#A"&`@);"@X(3`L"0`H."$$+3PX(`$`````X`0``
M3(G__]P`````0@X0CP)'#AB.`T(.((T$0@XHC`5$#C"&!E$.P"`"@@H.,$$.
M*$(.($(.&$(.$$(."$,+2````'P!``#HB?__,0(```!"#A"/`D(.&(X#0@X@
MC01"#BB,!4$.,(8&1`XX@P='#E`#%0$*#CA!#C!!#BA"#B!"#AA"#A!"#@A%
M"Q0```#(`0``W(O__VD`````1`X0`F`."!0```#@`0``-(S__S``````1`X0
M5@X(`#````#X`0``3(S__[\`````0@X0C`)!#AB&`T$.((,$1P[`0`*G"@X@
M1`X800X00@X(00L0````+`(``-B,__\%`````````%P```!``@``U(S__P("
M````0@X0CP)"#AB.`T(.((T$10XHC`5!#C"&!DL..(,'1P[P(0)D"@XX00XP
M00XH0@X@0@X80@X00@X(1`L"K@[X(4@.@")B#O@A00[P(0```!````"@`@``
MA([__R4`````````$````+0"``"@CO__'``````````H````R`(``*R.__^F
M!````$$.$(8"00X8@P-+#F`#1P0*#AA!#A!!#@A!"Q@```#T`@``,)/__W0`
M````1`X@;0H."$<+```4````$`,``)23__\=`````$0.$%@."`!,````*`,`
M`)R3__\+`0```$(.$(P"00X8A@-+#B"#!$0.,`)""@X@2@X800X00@X(3PMD
M"@X@00X800X00@X(2`MA#CA)#D!C#CA!#C```,P```!X`P``7)3__]4'````
M0@X0CP)"#AB.`T(.((T$3`XHC`5!#C"&!D$..(,'1P[`@P(#K`$.R(,"80[0
M@P)?#LB#`D(.P(,"`G@*#CA$#C!!#BA"#B!"#AA"#A!"#@A""P-Q`0[(@P))
M#M"#`F`.R(,"00[`@P);#LB#`D4.T(,"3@[8@P)-#N"#`DL.P(,"`P4!"@XX
M1`XP00XH0@X@0@X80@X00@X(30L#(@$.R(,"1`[0@P)H#LB#`D$.P(,"`NL*
M#LB#`D$.T(,"10LP````2`0``&R;__^=`@```$(.$(T"0@X8C`-!#B"&!$0.
M,`/6`0H.($$.&$(.$$(."$0+0````'P$``#8G?__/@$```!"#A",`D$.&(8#
M1`X@@P1$#C`"@@H.($$.&$$.$$(."$<+=`H.($0.&$$.$$(."$T+```H````
MP`0``"1___\/`@```$(.$(P"00X8A@-$#E`#I`$*#AA$#A!"#@A!"TP```#L
M!```J)[__QP6````0@X0CP)&#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1P[0
M!0/W%0H..$$.,$$.*$(.($(.&$(.$$(."$$+````%````#P%``!XM/__5```
M``!$#A`"3PX(2````%0%``#`M/__GP$```!"#A"/`D4.&(X#10X@C01"#BB,
M!40.,(8&10XX@P='#D`"Y0H..$$.,$$.*$(.($(.&$(.$$(."$,+`$````"@
M!0``%+;___L!````0@X0C@)&#AB-`T(.((P$00XHA@5$#C"#!@-*`0H.*$$.
M($(.&$(.$$(."$@+````````1````.0%``#0M___70````!"#A"/`DD.&(X#
M10X@C01%#BB,!40.,(8&2`XX@P='#D!J#CA!#C!!#BA"#B!"#AA"#A!"#@@`
M%````"P&``#HM___`0``````````````$````$0&``#@M___#```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````*`F````````8"8````````!`````````/("
M`````````0`````````"`P````````$`````````$@,````````,````````
M```@````````#0````````#\70```````!D`````````T+L````````;````
M``````@`````````&@````````#8NP```````!P`````````"`````````#U
M_O]O``````@#````````!0`````````@#0````````8`````````"`0`````
M```*`````````)T$````````"P`````````8`````````!4`````````````
M```````#`````````/"]`````````@`````````H!0```````!0`````````
M!P`````````7`````````(`4````````!P``````````$P````````@`````
M````@`$````````)`````````!@`````````'@`````````(`````````/O_
M_V\``````0``"`````#^__]O`````(`2````````____;P`````"````````
M`/#__V\`````OA$```````#Y__]O``````0`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#@NP``````````````````````````
M```V(````````$8@````````5B````````!F(````````'8@````````AB``
M``````"6(````````*8@````````MB````````#&(````````-8@````````
MYB````````#V(`````````8A````````%B$````````F(0```````#8A````
M````1B$```````!6(0```````&8A````````=B$```````"&(0```````)8A
M````````IB$```````"V(0```````,8A````````UB$```````#F(0``````
M`/8A````````!B(````````6(@```````"8B````````-B(```````!&(@``
M`````%8B````````9B(```````!V(@```````(8B````````EB(```````"F
M(@```````+8B````````QB(```````#6(@```````.8B````````]B(`````
M```&(P```````!8C````````)B,````````V(P```````$8C````````5B,`
M``````!F(P```````'8C````````AB,```````"6(P``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````_____P````#@8@```````$=#
M0SH@*$1E8FEA;B`Q,"XR+C$M-BD@,3`N,BXQ(#(P,C$P,3$P```N<VAS=')T
M86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N
M9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E
M<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YP;'0N9V]T`"YT
M97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN
M:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F1A=&$`+F)S<P`N8V]M
M;65N=```````````````````````````````````````````````````````
M````````````````````````````````````"P````$````"`````````*@"
M````````J`(````````<`````````````````````0``````````````````
M`!,````'`````@````````#$`@```````,0"````````)```````````````
M``````0````````````````````F````!P````(`````````Z`(```````#H
M`@```````"`````````````````````$````````````````````-````/;_
M_V\"``````````@#````````"`,```````#\``````````4`````````"```
M`````````````````#X````+`````@`````````(!`````````@$````````
M&`D````````&`````0````@`````````&`````````!&`````P````(`````
M````(`T````````@#0```````)T$```````````````````!````````````
M````````3@```/___V\"`````````+X1````````OA$```````#"````````
M``4``````````@`````````"`````````%L```#^__]O`@````````"`$@``
M`````(`2````````@``````````&`````@````@```````````````````!J
M````!`````(``````````!,`````````$P```````(`!````````!0``````
M```(`````````!@`````````=`````0```!"`````````(`4````````@!0`
M```````H!0````````4````6````"``````````8`````````'X````!````
M!@``````````(``````````@````````%P````````````````````0`````
M``````````````!Y`````0````8`````````("`````````@(````````(`#
M```````````````````0`````````!``````````A`````$````&````````
M`*`C````````H",````````(````````````````````"``````````(````
M`````(T````!````!@````````"P(P```````+`C````````3#H`````````
M`````````!````````````````````"3`````0````8`````````_%T`````
M``#\70````````D````````````````````$````````````````````F0``
M``$````"``````````!@`````````&````````"0/@``````````````````
M$````````````````````*$````!`````@````````"0G@```````)">````
M````!`$```````````````````0```````````````````"O`````0````(`
M````````F)\```````"8GP```````(@&```````````````````(````````
M````````````N0````X````#`````````-"[````````T*L````````(````
M````````````````"``````````(`````````,4````/`````P````````#8
MNP```````-BK````````"`````````````````````@`````````"```````
M``#1````!@````,`````````X+L```````#@JP```````!`"````````!@``
M```````(`````````!``````````B`````$````#`````````/"]````````
M\*T````````0`@``````````````````"``````````(`````````-H````!
M`````P``````````P`````````"P````````(`````````````````````@`
M``````````````````#@````"`````,`````````(,`````````@L```````
M`(`0```````````````````@````````````````````Y0````$````P````
M````````````````(+`````````G`````````````````````0`````````!
M``````````$````#`````````````````````````$>P````````[@``````
:``````````````$`````````````````````
